@@ -1,6 +1,6 @@
 /* apt-dater - terminal-based remote package update manager
  *
- * $Id: apt-dater.c 351 2009-05-15 11:15:04Z liske $
+ * $Id: apt-dater.c 438 2009-12-31 17:51:55Z liske $
  *
  * Authors:
  *   Andre Ellguth <ellguth@ibh.de>
@@ -39,6 +39,7 @@
 #include "stats.h"
 #include "sighandler.h"
 #include "lock.h"
+#include "env.h"
 
 #ifdef FEAT_XMLREPORT
 #include "report.h"
@@ -58,14 +59,20 @@ GMainLoop *loop = NULL;
 gboolean rebuilddl = FALSE;
 time_t oldest_st_mtime;
 
-int main(int argc, char **argv)
+int main(int argc, char **argv, char **envp)
 {
- char opts;
+ int opts;
  char *cfgfilename = NULL;
  char *cfgdirname = NULL;
  GList *hosts = NULL;
 #ifdef FEAT_XMLREPORT
  gboolean report = FALSE;
+ gboolean refresh = TRUE;
+#endif
+
+#ifdef HAVE_GETTEXT
+ setlocale(LC_ALL, "");
+ textdomain(PACKAGE);
 #endif
 
  cfgdirname = g_strdup_printf("%s/%s", g_get_user_config_dir(), PACKAGE);
@@ -80,7 +87,7 @@ int main(int argc, char **argv)
  if(chkForInitialConfig(cfgdirname, cfgfilename))
   g_warning(_("Failed to create initial configuration file %s."), cfgfilename);
 
- while ((opts = getopt(argc, argv, "c:vr")) != EOF) {
+ while ((opts = getopt(argc, argv, "c:vrn")) != EOF) {
   switch(opts) {
   case 'c':
    if(cfgfilename) free(cfgfilename);
@@ -97,8 +104,17 @@ int main(int argc, char **argv)
     g_error(_("Sorry, apt-dater was compiled w/o report feature!"));
 #endif
     break;
+#ifdef FEAT_XMLREPORT
+  case 'n':
+    refresh = FALSE;
+    break;
+#endif
   default:
-   g_printerr(_("Usage: %s [-(c config|v|r)]\n"), g_get_prgname());
+#ifdef FEAT_XMLREPORT
+   g_printerr(_("Usage: %s [-(c config|v|[n]r)]\n"), g_get_prgname());
+#else
+   g_printerr(_("Usage: %s [-(c config|v)]\n"), g_get_prgname());
+#endif
    exit(EXIT_FAILURE);
   }
  }
@@ -114,7 +130,11 @@ int main(int argc, char **argv)
   exit(EXIT_FAILURE);
  }
 
- if(cfg->ssh_agent) {
+ if(cfg->ssh_agent
+#ifdef FEAT_XMLREPORT
+ && (!report || refresh)
+#endif
+ ) {
 
   /* Spawn ssh-agent if needed */
   if(getenv("SSH_AGENT_PID") == NULL) {
@@ -151,6 +171,8 @@ int main(int argc, char **argv)
   }
  }
 
+ env_init(envp);
+
 #ifdef FEAT_XMLREPORT
  if(!report) {
 #endif
@@ -166,8 +188,12 @@ int main(int argc, char **argv)
    setSigHandler();
 #ifdef FEAT_XMLREPORT
  }
- else
-   initReport(hosts);
+ else {
+   if(refresh)
+    initReport(hosts);
+   else
+    initReport(NULL);
+ }
 #endif
 
  loop = g_main_loop_new (NULL, FALSE);
