@@ -1,6 +1,6 @@
 /* apt-dater - terminal-based remote package update manager
  *
- * $Id: apt-dater.h 358 2009-05-25 11:39:38Z liske $
+ * $Id: apt-dater.h 511 2010-03-25 16:40:06Z liske $
  *
  * Authors:
  *   Andre Ellguth <ellguth@ibh.de>
@@ -43,7 +43,7 @@
 #include <glib-2.0/glib/gstdio.h>
 
 #include "../config.h"
-
+#include "../include/adproto.h"
 
 #ifdef HAVE_GETTEXT
 
@@ -95,11 +95,10 @@ typedef struct _cfgfile {
  gchar *screenrcfile;
  gchar *screentitle;
  gchar *statsdir;
+ gchar *plugindir;
  gchar *ssh_cmd;
  gchar *sftp_cmd;
  gchar *ssh_optflags;
- gchar *ssh_defuser;
- gint  ssh_defport;
  gboolean ssh_agent;
  gchar **ssh_add;
  gsize ssh_numadd;
@@ -123,6 +122,14 @@ typedef struct _cfgfile {
 #ifdef FEAT_AUTOREF
  gboolean auto_refresh;
 #endif
+ gchar     *hook_pre_upgrade;
+ gchar     *hook_pre_refresh;
+ gchar     *hook_pre_install;
+ gchar     *hook_pre_connect;
+ gchar     *hook_post_upgrade;
+ gchar     *hook_post_refresh;
+ gchar     *hook_post_install;
+ gchar     *hook_post_connect;
 } CfgFile;
 
 typedef struct _update {
@@ -173,12 +180,17 @@ typedef enum {
 
 #define HOST_FORBID_MASK     (HOST_FORBID_REFRESH | HOST_FORBID_UPGRADE | HOST_FORBID_INSTALL)
 
+#define _QUOTE(x)                    #x
+#define QUOTE(x)              _QUOTE(x)
+#define UUID_STRLEN                  36
+
 typedef struct _hostnode {
 #ifndef NDEBUG
  etype _type;
 #endif
  gchar     *hostname;
  gchar     *group;
+ gchar     *type;
  gchar     *ssh_user;
  gint      ssh_port;
 #ifdef FEAT_AUTOREF
@@ -202,6 +214,7 @@ typedef struct _hostnode {
  GList     *screens;
  gint      fdlock;
  FILE      *fpstat;
+ gchar     *statsfile;
  gchar     *lsb_distributor;
  gchar     *lsb_release;
  gchar     *lsb_codename;
@@ -212,8 +225,12 @@ typedef struct _hostnode {
  gchar     *identity_file;
  gint      forbid;
  gboolean  tagged;
+ gchar     uuid[UUID_STRLEN+1];
 } HostNode;
 
+#define HOST_SSHPORT_SET(n) \
+ ((n)->ssh_port != 0)
+
 struct mapping_t {
  gchar *name;
  gint value;
