@@ -1,6 +1,6 @@
 /* apt-dater - terminal-based remote package update manager
  *
- * $Id: colors.c 300 2009-03-02 21:42:43Z liske $
+ * $Id: colors.c 425 2009-11-12 21:51:46Z liske $
  *
  * Authors:
  *   Andre Ellguth <ellguth@ibh.de>
@@ -25,9 +25,9 @@
  *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  */
 
-#include <curses.h>
 #include "apt-dater.h"
 #include "colors.h"
+#include "ui.h"
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
