@@ -1,6 +1,6 @@
 /* apt-dater - terminal-based remote package update manager
  *
- * $Id: exec.c 358 2009-05-25 11:39:38Z liske $
+ * $Id: exec.c 442 2010-01-11 11:49:39Z liske $
  *
  * Authors:
  *   Andre Ellguth <ellguth@ibh.de>
@@ -31,6 +31,7 @@
 #include "stats.h"
 #include "parsecmd.h"
 #include "history.h"
+#include "env.h"
 #include <glib.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -47,28 +48,22 @@ ssh_cmd_refresh(HostNode *n)
  gboolean r;
  GError *error = NULL;
  gchar *cmd = NULL;
- gchar **argv = NULL;
+ gchar *argv[2] = {PKGLIBDIR"/cmd", NULL};
  gchar *output = NULL;
- gchar *identity_file = NULL;
+ /* gchar *identity_file = NULL; */
  GPid  child_pid;
  gint  standard_output;
  GIOChannel *iocstdout;
 
  g_assert(n);
 
- cmd = g_strdup_printf("%s+-n+-o+BatchMode=yes+-o+ConnectTimeout=5+-q+-l+%s+-p+%d%s+%s+%s",
-		       cfg->ssh_cmd, n->ssh_user, n->ssh_port, 
-		       n->identity_file && strlen(n->identity_file) > 0 ? (identity_file = g_strconcat("+-i+", n->identity_file , NULL)) : "",
-		       n->hostname, cfg->cmd_refresh);
- g_free(identity_file);
-
- argv = g_strsplit(cmd, "+", 0);
-
  prepareStatsFile(n);
 
+ gchar **env = env_build(n, "refresh", NULL, NULL);
+
  r = g_spawn_async_with_pipes(g_getenv ("HOME"), /* working_directory */
 			      argv,
-			      NULL,  /* envp */
+			      env,  /* envp */
 			      G_SPAWN_STDERR_TO_DEV_NULL | G_SPAWN_SEARCH_PATH, /* GSpawnFlags */
 			      NULL,  /* GSpawnChildSetupFunc */
 			      NULL,  /* user_data */
@@ -78,6 +73,8 @@ ssh_cmd_refresh(HostNode *n)
 			      NULL,  /* standard_error */
 			      &error);
 
+ g_strfreev(env);
+
  if(r == TRUE) {
   iocstdout = g_io_channel_unix_new (standard_output);
 
@@ -93,11 +90,10 @@ ssh_cmd_refresh(HostNode *n)
  if(r == FALSE) {
   g_warning("%s", error->message);
   g_clear_error (&error);
- } 
+ }
 
  g_free(output);
  g_free(cmd);
- g_strfreev(argv);
 
  return r;
 }
@@ -109,8 +105,6 @@ ssh_cmd_upgrade(HostNode *n, const gboolean detached)
  gboolean r;
  GError *error = NULL;
  gchar *cmd = NULL;
- gchar *optflags = NULL;
- gchar *identity_file = NULL;
  gchar **argv = NULL;
 
  g_assert(n);
@@ -124,16 +118,10 @@ ssh_cmd_upgrade(HostNode *n, const gboolean detached)
  he.action = "upgrade";
  he.data = NULL;
 
- gchar *screen = screen_new(n, detached, &he);
+ gchar *screen = screen_new(n, detached);
 
- cmd = g_strdup_printf ("%s%s+-l+%s+-p+%d%s%s+%s+%s", 
-			screen,
-			cfg->ssh_cmd, n->ssh_user, n->ssh_port, 
-			cfg->ssh_optflags && strlen(cfg->ssh_optflags) > 0 ? (optflags = g_strconcat("+", cfg->ssh_optflags , NULL)) : "",
-			n->identity_file && strlen(n->identity_file) > 0 ? (identity_file = g_strconcat("+-i+", n->identity_file , NULL)) : "",
-			n->hostname, cfg->cmd_upgrade);
- g_free(optflags);
- g_free(identity_file);
+ cmd = g_strdup_printf ("%s%s",
+			screen, PKGLIBDIR"/cmd");
  g_free(screen);
 
 #ifdef FEAT_HISTORY
@@ -142,18 +130,22 @@ ssh_cmd_upgrade(HostNode *n, const gboolean detached)
 
  argv = g_strsplit(cmd, "+", 0);
 
- r = g_spawn_sync(g_getenv ("HOME"), argv, NULL, 
+ g_free(cmd);
+
+ gchar **env = env_build(n, "upgrade", NULL, &he);
+
+ r = g_spawn_sync(g_getenv ("HOME"), argv, env,
 		  G_SPAWN_CHILD_INHERITS_STDIN, NULL, NULL,
 		  NULL, NULL, NULL, &error);
 
+ g_strfreev(env);
+ g_strfreev(argv);
+
  if(r == FALSE) {
   g_warning("%s", error->message);
   g_clear_error (&error);
  }
 
- g_free(cmd);
- g_strfreev(argv);
-
 #ifdef FEAT_HISTORY
  if(!detached && n->parse_result && !screen_get_sessions(n)) {
     n->parse_result = FALSE;
@@ -170,9 +162,6 @@ ssh_cmd_install(HostNode *n, gchar *package, const gboolean detached)
  gboolean r;
  GError *error = NULL;
  gchar *cmd = NULL;
- gchar *buf = NULL;
- gchar *optflags = NULL;
- gchar *identity_file = NULL;
  gchar **argv = NULL;
 
  g_assert(n);
@@ -186,41 +175,35 @@ ssh_cmd_install(HostNode *n, gchar *package, const gboolean detached)
  he.action = "install";
  he.data = package;
 
- gchar *screen = screen_new(n, detached, &he);
+ gchar *screen = screen_new(n, detached);
+
+ cmd = g_strdup_printf ("%s%s",
+			screen, PKGLIBDIR"/cmd");
 
- cmd = g_strdup_printf ("%s%s+-l+%s+-p+%d%s%s+%s+%s", 
-			screen,
-			cfg->ssh_cmd, n->ssh_user, n->ssh_port, 
-			cfg->ssh_optflags && strlen(cfg->ssh_optflags) > 0 ? (optflags = g_strconcat("+", cfg->ssh_optflags , NULL)) : "",
-			n->identity_file && strlen(n->identity_file) > 0 ? (identity_file = g_strconcat("+-i+", n->identity_file , NULL)) : "",
-			n->hostname, cfg->cmd_install);
- g_free(optflags);
- g_free(identity_file);
  g_free(screen);
 
- buf = g_strdup_printf (cmd, package);
-
- g_free(cmd);
- cmd = buf;
-
 #ifdef FEAT_HISTORY
  n->parse_result = cfg->history_errpattern && strlen(cfg->history_errpattern);
 #endif
 
  argv = g_strsplit(cmd, "+", 0);
 
- r = g_spawn_sync(g_getenv ("HOME"), argv, NULL, 
+ g_free(cmd);
+
+ gchar **env = env_build(n, "install", package, &he);
+
+ r = g_spawn_sync(g_getenv ("HOME"), argv, env,
 		  G_SPAWN_CHILD_INHERITS_STDIN, NULL, NULL,
 		  NULL, NULL, NULL, &error);
 
+ g_strfreev(env);
+ g_strfreev(argv);
+
  if(r == FALSE) {
   g_warning("%s", error->message);
   g_clear_error (&error);
  }
 
- g_free(cmd);
- g_strfreev(argv);
-
 #ifdef FEAT_HISTORY
  if(!detached && n->parse_result && !screen_get_sessions(n)) {
     n->parse_result = FALSE;
@@ -236,9 +219,7 @@ void ssh_connect(HostNode *n, const gboolean detached)
  gboolean r;
  GError *error = NULL;
  gchar *cmd = NULL;
- gchar *optflags = NULL;
- gchar *identity_file = NULL;
- gchar **argv = NULL;
+ gchar **argv;
 
  HistoryEntry he;
  he.ts = time(NULL);
@@ -246,72 +227,69 @@ void ssh_connect(HostNode *n, const gboolean detached)
  he.action = "connect";
  he.data = NULL;
 
- gchar *screen = screen_new(n, detached, &he);
+ gchar *screen = screen_new(n, detached);
+
+ cmd = g_strdup_printf ("%s%s",
+			screen, PKGLIBDIR"/cmd");
 
- cmd = g_strdup_printf ("%s%s+-l+%s+-t+-p+%d%s%s+%s",
-			screen,
-			cfg->ssh_cmd, n->ssh_user, n->ssh_port, 
-			cfg->ssh_optflags && strlen(cfg->ssh_optflags) > 0 ? (optflags = g_strconcat("+", cfg->ssh_optflags , NULL)) : "",
-			n->identity_file && strlen(n->identity_file) > 0 ? (identity_file = g_strconcat("+-i+", n->identity_file , NULL)) : "",
-			n->hostname);
- g_free(optflags);
- g_free(identity_file);
  g_free(screen);
 
  argv = g_strsplit(cmd, "+", 0);
 
- r = g_spawn_sync(g_getenv ("HOME"), argv, NULL, 
+ g_free(cmd);
+
+ gchar **env = env_build(n, "connect", NULL, &he);
+
+ r = g_spawn_sync(g_getenv("HOME"), argv, env,
 		  G_SPAWN_CHILD_INHERITS_STDIN, NULL, NULL,
 		  NULL, NULL, NULL, &error);
 
+ g_strfreev(env);
+ g_strfreev(argv);
+
  if(r == FALSE) {
   g_warning("%s", error->message);
   g_clear_error (&error);
  }
-
- g_free(cmd);
- g_strfreev(argv);
 }
 
 void sftp_connect(HostNode *n)
 {
  gboolean r;
  GError *error = NULL;
- gint argc = 0;
- gchar **argv = NULL;
+ gchar *cmd = NULL;
+ gchar **argv;
 
  g_assert(n);
 
  HistoryEntry he;
  he.ts = time(NULL);
  he.maintainer = maintainer;
- he.action = "sftp";
+ he.action = "transfer";
  he.data = NULL;
 
- gchar *cmd = screen_new(n, FALSE, &he);
+ gchar *screen = screen_new(n, FALSE);
 
- cmd = g_realloc(cmd, strlen(cmd) + strlen(cfg->sftp_cmd) + 1);
- strcat(cmd, cfg->sftp_cmd);
+ cmd = g_strdup_printf ("%s%s",
+			screen, PKGLIBDIR"/cmd");
 
- if (parse_cmdline(cmd, &argc, &argv, n) < 0) {
-   g_free(cmd);
-   return;
- }
- g_free(cmd);
-
- cmd = g_strjoinv("+", argv);
- g_strfreev(argv);
+ g_free(screen);
 
  argv = g_strsplit(cmd, "+", 0);
 
- r = g_spawn_sync(g_getenv ("HOME"), argv, NULL, 
+ g_free(cmd);
+
+ gchar **env = env_build(n, "transfer", NULL, &he);
+
+ r = g_spawn_sync(g_getenv("HOME"), argv, env,
 		  G_SPAWN_CHILD_INHERITS_STDIN, NULL, NULL,
 		  NULL, NULL, NULL, &error);
 
+ g_strfreev(env);
+ g_strfreev(argv);
+
  if(r == FALSE) {
   g_warning("%s", error->message);
   g_clear_error (&error);
  }
-
- g_strfreev(argv);
 }
