@@ -1,6 +1,6 @@
 /* apt-dater - terminal-based remote package update manager
  *
- * $Id: exec.h 200 2008-08-27 18:30:15Z liske $
+ * $Id: exec.h 358 2009-05-25 11:39:38Z liske $
  *
  * Authors:
  *   Andre Ellguth <ellguth@ibh.de>
@@ -37,12 +37,12 @@ gboolean
 ssh_cmd_upgrade(HostNode *n, const gboolean detached);
 
 gboolean
-ssh_cmd_install(HostNode *n, const gchar *package, const gboolean detached);
+ssh_cmd_install(HostNode *n, gchar *package, const gboolean detached);
 
-gboolean
+void
 ssh_connect(HostNode *n, const gboolean detached);
 
-gboolean
+void
 sftp_connect(HostNode *n);
 
 #endif /* _EXEC_H */
