@@ -1,6 +1,6 @@
 /* apt-dater - terminal-based remote package update manager
  *
- * $Id: screen.h 358 2009-05-25 11:39:38Z liske $
+ * $Id: screen.h 484 2010-02-21 15:37:06Z liske $
  *
  * Authors:
  *   Andre Ellguth <ellguth@ibh.de>
@@ -32,13 +32,12 @@
 #include "history.h"
 
 #define SCREEN_SDFORMT "%s/S-%s"
-#define SCREEN_SOCKDIR "/var/run/screen"
 #define SCREEN_SOCKPRE "apt-dater_"
 
 gboolean
 screen_get_sessions(HostNode *n);
 
-gchar *screen_new(HostNode *n, const gboolean detached, const HistoryEntry *he);
+gchar *screen_new(HostNode *n, const gboolean detached);
 gboolean screen_attach(HostNode *n, const SessNode *s, const gboolean shared);
 gchar *screen_get_dump(const SessNode *s);
 
