@@ -1,6 +1,6 @@
 /* apt-dater - terminal-based remote package update manager
  *
- * $Id: stats.c 364 2009-05-26 07:23:14Z ellguth $
+ * $Id: stats.c 432 2009-12-09 18:44:42Z liske $
  *
  * Authors:
  *   Andre Ellguth <ellguth@ibh.de>
@@ -40,32 +40,17 @@
 
 gchar *getStatsFile(const HostNode *n)
 {
- gchar *statsfile = getStatsFileName(n);
+ if(g_file_test(n->statsfile, G_FILE_TEST_IS_REGULAR | G_FILE_TEST_EXISTS) == FALSE)
+   return NULL;
 
- if(g_file_test(statsfile, G_FILE_TEST_IS_REGULAR | G_FILE_TEST_EXISTS) == FALSE) {
-   g_free(statsfile);
-   statsfile = NULL;
- }
-
- return(statsfile);
+ return n->statsfile;
 }
 
-
-gchar *getStatsFileName(const HostNode *n)
-{
- return g_strdup_printf("%s/%s:%d.stat", cfg->statsdir, n->hostname, n->ssh_port);
-}
-
-
 gboolean prepareStatsFile(HostNode *n)
 {
- gchar *statsfile = getStatsFileName(n);
+ g_unlink(n->statsfile);
 
- g_unlink(statsfile);
-
- n->fpstat = fopen(statsfile, "wx");
-
- g_free(statsfile);
+ n->fpstat = fopen(n->statsfile, "wx");
 
  return n->fpstat != NULL;
 }
@@ -171,30 +156,31 @@ static gint cmpPackages(gconstpointer a, gconstpointer b) {
 
 gboolean getUpdatesFromStat(HostNode *n)
 {
- gchar *statsfile;
  char line[STATS_MAX_LINE_LEN];
  char buf[256] = "\0";
  FILE  *fp;
  PkgNode *pkgnode = NULL;
  gint status=0, i;
  gchar **argv = NULL;
+ gboolean adproto = FALSE;
+ gfloat adpver = 0;
+ gboolean adperr = FALSE;
 
  if(!n) return (FALSE);
 
- if(!(statsfile = getStatsFile(n))) {
+ if(!getStatsFile(n)) {
   n->category = C_UNKNOWN;
   return (TRUE);
  }
 
 #ifdef FEAT_AUTOREF
  struct stat sbuf;
- if(!stat(statsfile, &sbuf))
+ if(!stat(n->statsfile, &sbuf))
   n->last_upd = sbuf.st_mtime;
 #endif
 
- if(!(fp = (FILE *) g_fopen(statsfile, "r"))) {
+ if(!(fp = (FILE *) g_fopen(n->statsfile, "r"))) {
   n->category = C_UNKNOWN;
-  g_free(statsfile);
   return (TRUE);
  }
 
@@ -204,6 +190,7 @@ gboolean getUpdatesFromStat(HostNode *n)
  n->nholds = 0;
  n->nbrokens = 0;
  n->forbid = 0;
+ n->uuid[0] = 0;
 
  freePackages(n);
 
@@ -241,7 +228,7 @@ gboolean getUpdatesFromStat(HostNode *n)
   /* Remove any whitespace from the line. */
   g_strchomp(line);
 
-  if (sscanf((gchar *) line, "KERNELINFO: %d %255s", &status, buf) && !n->kernelrel) {
+  if (sscanf((gchar *) line, ADP_PATTERN_KERNELINFO, &status, buf) && !n->kernelrel) {
    n->kernelrel = g_strdup(buf);
    switch(status){
    case 1:
@@ -255,6 +242,17 @@ gboolean getUpdatesFromStat(HostNode *n)
    continue;
   }
 
+  if(sscanf(line, ADP_PATTERN_ADPROTO, &adpver)) {
+    adproto = TRUE;
+    continue;
+  }
+
+// ADP_PATTERN_ADPERR
+  if(!strncmp("ADPERR: ", line, 8)) {
+    adperr = TRUE;
+    continue;
+  }
+
   if(!strncmp("STATUS: ", line, 8)) {
     argv = g_strsplit(&line[8], "|", 0);
 
@@ -343,7 +341,7 @@ gboolean getUpdatesFromStat(HostNode *n)
    continue;
   }
 
-  if (sscanf((gchar *) line, "VIRT: %255s", buf)) {
+  if (sscanf((gchar *) line, ADP_PATTERN_VIRT, buf)) {
    n->virt = g_strdup(buf);
 
    if (strcmp(n->virt, "Unknown") && strcmp(n->virt, "Physical"))
@@ -353,7 +351,7 @@ gboolean getUpdatesFromStat(HostNode *n)
    continue;
   }
 
-  if (sscanf((gchar *) line, "UNAME: %255s", buf)) {
+  if (sscanf((gchar *) line, ADP_PATTERN_UNAME, buf)) {
    gchar *s = strchr(buf, '|');
    if (s) {
     s[0] = 0;
@@ -366,11 +364,20 @@ gboolean getUpdatesFromStat(HostNode *n)
    continue;
   }
 
-  if (sscanf((gchar *) line, "FORBID: %d", &n->forbid))
+  if (sscanf((gchar *) line, ADP_PATTERN_FORBID, &n->forbid))
    continue;
+
+  if (sscanf((gchar *) line, "UUID: %" QUOTE(UUID_STRLEN) "s", n->uuid)) {
+   n->uuid[UUID_STRLEN] = 0;
+
+   linesok++;
+   continue;
+  }
  }
 
- if(linesok>5) {
+ if((!adproto && linesok > 10) ||
+    (adproto && adpver < ADP_FEATVER_ADPERR && linesok > 10) ||
+    (adproto && adpver >= ADP_FEATVER_ADPERR && !adperr)) {
    if (n->status & HOST_STATUS_PKGBROKEN)
     n->category = C_BROKEN_PKGS;
    else if(n->status & HOST_STATUS_PKGUPDATE)
@@ -385,7 +392,6 @@ gboolean getUpdatesFromStat(HostNode *n)
     n->category = C_UNKNOWN;
 
  fclose(fp);
- g_free(statsfile);
 
  return(TRUE);
 }
@@ -489,7 +495,6 @@ gboolean refreshStats(GList *hosts)
 void getOldestMtime(GList *hosts)
 {
  GList *ho;
- gchar *statsfile;
  struct stat stat_p;
  HostNode *n;
 
@@ -500,14 +505,12 @@ void getOldestMtime(GList *hosts)
  while(ho) {
   n = (HostNode *) ho->data;
 
-  if((statsfile = getStatsFile(n)))
+  if(getStatsFile(n))
    {
-    if(!stat(statsfile, &stat_p)) {
+    if(!stat(n->statsfile, &stat_p)) {
      if(difftime(stat_p.st_mtime, oldest_st_mtime) < 0)
       oldest_st_mtime = stat_p.st_mtime;
     }
-
-    g_free(statsfile);
    }
 
   ho = g_list_next(ho);
