@@ -1,6 +1,6 @@
 /* apt-dater - terminal-based remote package update manager
  *
- * $Id: ui.h 355 2009-05-22 14:23:14Z ellguth $
+ * $Id: ui.h 503 2010-03-18 09:48:16Z ellguth $
  *
  * Authors:
  *   Andre Ellguth <ellguth@ibh.de>
@@ -29,7 +29,12 @@
 #ifndef _UI_H
 #define _UI_H
 
+#ifdef HAVE_NCURSES_H
+#include <ncurses.h>
+#else
 #include <curses.h>
+#endif
+
 #include <glib-2.0/glib.h>
 
 typedef enum {
@@ -95,6 +100,7 @@ typedef enum {
  SC_KEY_TAG,
  SC_KEY_TAGMATCH,
  SC_KEY_UNTAGMATCH,
+ SC_KEY_UNUSED,
  SC_MAX,
 } EShortCuts;
 
@@ -115,6 +121,12 @@ typedef struct _drawnode {
  struct _drawnode *parent;
 } DrawNode;
 
+struct HostFlag {
+  gint flag;
+  gchar *code;
+  gchar *descr;
+};
+
 gboolean
 ctrlKeyEnter(GList *hosts);
 
@@ -137,6 +149,7 @@ void drawStatus (char *str, gboolean drawoldest);
 
 extern gchar maintainer[48];
 extern gchar *drawCategories[];
+extern const struct HostFlag hostFlags[];
 
 #ifndef KEY_RETURN
 # define KEY_RETURN   13
